@@ -368,12 +368,7 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if (test == "testIndReg") ## It uMMPC the F test
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
-        
+
         #an einai posostiaio target
         if ( min(target) > 0 & max(target) < 1 ) {
           target = log(target/(1-target)) ## logistic normal 
@@ -391,11 +386,7 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }     
       else if(test == "testIndBeta") ## beta regression for proportions
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         test = testIndBeta;
         if(requireNamespace("betareg", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
         {
@@ -405,12 +396,7 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if(test == "testIndRQ") ## beta regression for proportions
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
-        
+
         #an einai posostiaio target
         if ( all( target>0 & target<1 ) ){
           target = log( target/(1 - target) ) ## logistic normal 
@@ -425,48 +411,28 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if (test == "testIndPois") ## Poisson regression
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         test = testIndPois;
       }
       else if (test == "testIndSpeedglm") ## Poisson regression
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         test = testIndSpeedglm;
       }
       else if (test == "testIndNB") ## Negative binomial regression
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         
         test = testIndNB;
       }
       else if (test == "testIndZIP") ## Poisson regression
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         test = testIndZIP;
       }
       else if(test == "censIndCR")
       {
-        #dataframe class for dataset is required
-        #if(class(dataset) == "matrix"){
-        #  dataset = as.data.frame(dataset)
-        #  warning("Dataset was turned into a data.frame which is required for this test")
-        #}
+
         test = censIndCR;
         if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
         {
@@ -476,11 +442,7 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if(test == "censIndWR")
       {
-        #dataframe class for dataset is required
-        #if(class(dataset) == "matrix"){
-        #  dataset = as.data.frame(dataset)
-        #  warning("Dataset was turned into a data.frame which is required for this test")
-        #}
+
         test = censIndWR;
         if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
         {
@@ -490,11 +452,7 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if(test == "testIndClogit")
       {
-        #dataframe class for dataset is required
-        #if(class(dataset) == "matrix"){
-        #  dataset = as.data.frame(dataset)
-        #  warning("Dataset was turned into a data.frame which is required for this test")
-        #}
+
         test = testIndClogit;
         if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
         {
@@ -504,20 +462,12 @@ MMPC = function(target , dataset , max_k = 3 , threshold = 0.05 , test = NULL ,
       }
       else if(test == "testIndBinom")
       {
-        #dataframe class for dataset is required
-        #if(class(dataset) == "matrix"){
-        #  dataset = as.data.frame(dataset)
-        #  warning("Dataset was turned into a data.frame which is required for this test")
-        #}
+
         test = testIndBinom;
       }
       else if(test == "testIndLogistic")
       {
-        #dataframe class for dataset is required
-        if(class(dataset) == "matrix"){
-          dataset = as.data.frame(dataset)
-          warning("Dataset was turned into a data.frame which is required for this test")
-        }
+
         test = testIndLogistic;
       }
       else if(test == "gSquare")
@@ -772,6 +722,14 @@ InternalMMPC = function(target , dataset , max_k, threshold , test = NULL , ini
         univariateModels$pvalue_hash = NULL   
       }   
       
+    } else if ( identical(test, testIndReg) == TRUE && robust == FALSE  && is.matrix(dataset) ) {  ## M (Robust) linear regression
+      
+      mod = Rfast::univglms(target, dataset, logged = TRUE) 
+      univariateModels$stat = mod[, 1]
+      univariateModels$pvalue = mod[, 2]
+      univariateModels$flag = numeric(cols) + 1;
+      univariateModels$stat_hash = stat_hash;
+      univariateModels$pvalue_hash = pvalue_hash;
       
     } else if ( identical(test, testIndLogistic) == TRUE  &&  is.ordered(target) == TRUE  ) {  ## 
       
@@ -903,6 +861,28 @@ InternalMMPC = function(target , dataset , max_k, threshold , test = NULL , ini
             univariateModels$pvalue_hash = NULL   
           }
           
+      } else if ( identical(test, testIndLogistic) == TRUE  &&  length( unique(target) ) == 2  && is.matrix(dataset) ) {  ## 
+        
+        if ( is.factor(target) ) {
+          target <- as.numeric(target) - 1
+        }
+        mod = Rfast::univglms(target, dataset, "binomial", logged = TRUE)
+        
+        univariateModels$stat = mod[, 1]
+        univariateModels$pvalue = mod[, 2]
+        univariateModels$flag = numeric(cols) + 1;
+        univariateModels$stat_hash = stat_hash;
+        univariateModels$pvalue_hash = pvalue_hash;
+        
+      } else if ( identical(test, testIndPois) == TRUE  && is.matrix(dataset) ) {  ## 
+        
+        mod = Rfast::univglms(target, dataset, "poisson", logged = TRUE)
+        
+        univariateModels$stat = mod[, 1]
+        univariateModels$pvalue = mod[, 2]
+        univariateModels$flag = numeric(cols) + 1;
+        univariateModels$stat_hash = stat_hash;
+        univariateModels$pvalue_hash = pvalue_hash;
       
     } else if ( identical(test, testIndZIP) == TRUE ) {  ## Zero-inflated Poisson regression
       
@@ -981,7 +961,7 @@ InternalMMPC = function(target , dataset , max_k, threshold , test = NULL , ini
             pval[i] = pf(stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE)
           } else {
             pval[i] = log(1);
-            stat[[i]] = 0;
+            stat[i] = 0;
           }
         }
         
