@@ -29,7 +29,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
   #initialization
   
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
   flag = 0;
 
@@ -64,9 +64,9 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
     if(hash == TRUE)#update hash objects
     {
       stat_hash$key <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash$key <- 1;#.set(pvalue_hash , key , 1)
+      pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
@@ -117,9 +117,9 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
         if(hash == TRUE)#update hash objects
         {
           stat_hash$key <- 0;#.set(stat_hash , key , 0)
-          pvalue_hash$key <- 1;#.set(pvalue_hash , key , 1)
+          pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     }else{ #more than one var
@@ -130,9 +130,9 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
           if(hash == TRUE)#update hash objects
           {
             stat_hash$key <- 0;#.set(stat_hash , key , 0)
-            pvalue_hash$key <- 1;#.set(pvalue_hash , key , 1)
+            pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -145,9 +145,9 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
     if(hash == TRUE)#update hash objects
     {
       stat_hash$key <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash$key <- 1;#.set(pvalue_hash , key , 1)
+      pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
@@ -185,7 +185,7 @@ testIndMVreg = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univari
   #last error check
   if(is.na(pvalue) || is.na(stat))
   {
-    pvalue = 1;
+    pvalue = log(1);
     stat = 0;
     flag = 0;
   }else{
@@ -218,7 +218,7 @@ error=function(cond) {
   stop();
   
   #error case
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
   flag = 0;
   
